# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: global_vo_grpc_service/protos/image_api.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from global_vo_grpc_service.protos import utils_pb2 as global__vo__grpc__service_dot_protos_dot_utils__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-global_vo_grpc_service/protos/image_api.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a)global_vo_grpc_service/protos/utils.proto\"\xd0\x01\n\x05Image\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05width\x18\x03 \x01(\x05\x12\x0e\n\x06height\x18\x04 \x01(\x05\x12\x1a\n\x08geo_bbox\x18\x05 \x01(\x0b\x32\x08.GeoBbox\x12\x12\n\nfeature_id\x18\x06 \x01(\x05\x12.\n\ncreated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"1\n\x18\x46indOrCreateImageRequest\x12\x15\n\x05image\x18\x01 \x01(\x0b\x32\x06.Image\"T\n\x19\x46indOrCreateImageResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x15\n\x05image\x18\x02 \x01(\x0b\x32\x06.Image\",\n\x13GetImageByIdRequest\x12\x15\n\x05image\x18\x01 \x01(\x0b\x32\x06.Image\"O\n\x14GetImageByIdResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x15\n\x05image\x18\x02 \x01(\x0b\x32\x06.Image2\x93\x01\n\x08ImageApi\x12J\n\x11\x46indOrCreateImage\x12\x19.FindOrCreateImageRequest\x1a\x1a.FindOrCreateImageResponse\x12;\n\x0cGetImageById\x12\x14.GetImageByIdRequest\x1a\x15.GetImageByIdResponseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'global_vo_grpc_service.protos.image_api_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _IMAGE._serialized_start=126
  _IMAGE._serialized_end=334
  _FINDORCREATEIMAGEREQUEST._serialized_start=336
  _FINDORCREATEIMAGEREQUEST._serialized_end=385
  _FINDORCREATEIMAGERESPONSE._serialized_start=387
  _FINDORCREATEIMAGERESPONSE._serialized_end=471
  _GETIMAGEBYIDREQUEST._serialized_start=473
  _GETIMAGEBYIDREQUEST._serialized_end=517
  _GETIMAGEBYIDRESPONSE._serialized_start=519
  _GETIMAGEBYIDRESPONSE._serialized_end=598
  _IMAGEAPI._serialized_start=601
  _IMAGEAPI._serialized_end=748
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: global_vo_grpc_service/protos/feature_api.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from global_vo_grpc_service.protos import utils_pb2 as global__vo__grpc__service_dot_protos_dot_utils__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/global_vo_grpc_service/protos/feature_api.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a)global_vo_grpc_service/protos/utils.proto\x1a\x1cgoogle/protobuf/struct.proto\"\xc7\x01\n\x07\x46\x65\x61ture\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x13\n\x0bvendor_name\x18\x02 \x01(\t\x12\x11\n\tvendor_id\x18\x03 \x01(\t\x12(\n\x07\x66\x65\x61ture\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12.\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"+\n\x0e\x46\x65\x61tureRequest\x12\x19\n\x07\x66\x65\x61ture\x18\x01 \x01(\x0b\x32\x08.Feature\"N\n\x0f\x46\x65\x61tureResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x19\n\x07\x66\x65\x61ture\x18\x02 \x01(\x0b\x32\x08.Feature\"3\n\x16\x46indFeatureByIdRequest\x12\x19\n\x07\x66\x65\x61ture\x18\x01 \x01(\x0b\x32\x08.Feature\"V\n\x17\x46indFeatureByIdResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x19\n\x07\x66\x65\x61ture\x18\x02 \x01(\x0b\x32\x08.Feature2\x8c\x01\n\nFeatureApi\x12\x38\n\x13\x46indOrCreateFeature\x12\x0f.FeatureRequest\x1a\x10.FeatureResponse\x12\x44\n\x0f\x46indFeatureById\x12\x17.FindFeatureByIdRequest\x1a\x18.FindFeatureByIdResponseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'global_vo_grpc_service.protos.feature_api_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _FEATURE._serialized_start=158
  _FEATURE._serialized_end=357
  _FEATUREREQUEST._serialized_start=359
  _FEATUREREQUEST._serialized_end=402
  _FEATURERESPONSE._serialized_start=404
  _FEATURERESPONSE._serialized_end=482
  _FINDFEATUREBYIDREQUEST._serialized_start=484
  _FINDFEATUREBYIDREQUEST._serialized_end=535
  _FINDFEATUREBYIDRESPONSE._serialized_start=537
  _FINDFEATUREBYIDRESPONSE._serialized_end=623
  _FEATUREAPI._serialized_start=626
  _FEATUREAPI._serialized_end=766
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: global_vo_grpc_service/protos/category_api.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from global_vo_grpc_service.protos import utils_pb2 as global__vo__grpc__service_dot_protos_dot_utils__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0global_vo_grpc_service/protos/category_api.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a)global_vo_grpc_service/protos/utils.proto\"\xfd\x01\n\x08\x43\x61tegory\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x65num\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12)\n\x08includes\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12)\n\x08\x65xcludes\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12.\n\ncreated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\".\n\x0f\x43\x61tegoryRequest\x12\x1b\n\x08\x63\x61tegory\x18\x01 \x01(\x0b\x32\t.Category\"Q\n\x10\x43\x61tegoryResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x1b\n\x08\x63\x61tegory\x18\x02 \x01(\x0b\x32\t.Category\"Y\n\x16ListCategoriesResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x1d\n\ncategories\x18\x02 \x03(\x0b\x32\t.Category2\x8d\x01\n\x0b\x43\x61tegoryApi\x12;\n\x14\x46indOrCreateCategory\x12\x10.CategoryRequest\x1a\x11.CategoryResponse\x12\x41\n\x0eListCategories\x12\x16.google.protobuf.Empty\x1a\x17.ListCategoriesResponseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'global_vo_grpc_service.protos.category_api_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CATEGORY._serialized_start=188
  _CATEGORY._serialized_end=441
  _CATEGORYREQUEST._serialized_start=443
  _CATEGORYREQUEST._serialized_end=489
  _CATEGORYRESPONSE._serialized_start=491
  _CATEGORYRESPONSE._serialized_end=572
  _LISTCATEGORIESRESPONSE._serialized_start=574
  _LISTCATEGORIESRESPONSE._serialized_end=663
  _CATEGORYAPI._serialized_start=666
  _CATEGORYAPI._serialized_end=807
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: geospatial_toolkit_grpc_service/protos/function_api.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9geospatial_toolkit_grpc_service/protos/function_api.proto\"E\n\x14\x43\x61lculateAMSLRequest\x12\x0b\n\x03lat\x18\x01 \x01(\x02\x12\x0b\n\x03lon\x18\x02 \x01(\x02\x12\x13\n\x0bheight_feet\x18\x03 \x01(\x02\"B\n\x15\x43\x61lculateAMSLResponse\x12\x11\n\tamsl_feet\x18\x01 \x01(\x02\x12\x16\n\x0e\x65levation_feet\x18\x02 \x01(\x02\"M\n\"ExtractShapesFromFilesAsWKTRequest\x12\x11\n\tfile_name\x18\x01 \x01(\t\x12\x14\n\x0c\x66ile_content\x18\x02 \x01(\x0c\"L\n#ExtractShapesFromFilesAsWKTResponse\x12\x11\n\tfile_name\x18\x01 \x01(\t\x12\x12\n\nwkt_shapes\x18\x02 \x03(\t2\xbb\x01\n\x0b\x46unctionApi\x12>\n\rCalculateAMSL\x12\x15.CalculateAMSLRequest\x1a\x16.CalculateAMSLResponse\x12l\n\x1b\x45xtractShapesFromFilesAsWKT\x12#.ExtractShapesFromFilesAsWKTRequest\x1a$.ExtractShapesFromFilesAsWKTResponse(\x01\x30\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'geospatial_toolkit_grpc_service.protos.function_api_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CALCULATEAMSLREQUEST._serialized_start=61
  _CALCULATEAMSLREQUEST._serialized_end=130
  _CALCULATEAMSLRESPONSE._serialized_start=132
  _CALCULATEAMSLRESPONSE._serialized_end=198
  _EXTRACTSHAPESFROMFILESASWKTREQUEST._serialized_start=200
  _EXTRACTSHAPESFROMFILESASWKTREQUEST._serialized_end=277
  _EXTRACTSHAPESFROMFILESASWKTRESPONSE._serialized_start=279
  _EXTRACTSHAPESFROMFILESASWKTRESPONSE._serialized_end=355
  _FUNCTIONAPI._serialized_start=358
  _FUNCTIONAPI._serialized_end=545
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from data_grpc_service.protos import detection_instance_data_api_pb2 as data__grpc__service_dot_protos_dot_detection__instance__data__api__pb2


class DetectionInstanceDataApiStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CacheDetectionInstancesDataByImageId = channel.unary_unary(
                '/DetectionInstanceDataApi/CacheDetectionInstancesDataByImageId',
                request_serializer=data__grpc__service_dot_protos_dot_detection__instance__data__api__pb2.CacheDetectionInstancesDataByImageIdRequest.SerializeToString,
                response_deserializer=data__grpc__service_dot_protos_dot_detection__instance__data__api__pb2.CacheDetectionInstancesDataByImageIdResponse.FromString,
                )
        self.GetDetectionInstanceDataById = channel.unary_stream(
                '/DetectionInstanceDataApi/GetDetectionInstanceDataById',
                request_serializer=data__grpc__service_dot_protos_dot_detection__instance__data__api__pb2.GetDetectionInstanceDataByIdRequest.SerializeToString,
                response_deserializer=data__grpc__service_dot_protos_dot_detection__instance__data__api__pb2.GetDetectionInstanceDataByIdResponse.FromString,
                )


class DetectionInstanceDataApiServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CacheDetectionInstancesDataByImageId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDetectionInstanceDataById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DetectionInstanceDataApiServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CacheDetectionInstancesDataByImageId': grpc.unary_unary_rpc_method_handler(
                    servicer.CacheDetectionInstancesDataByImageId,
                    request_deserializer=data__grpc__service_dot_protos_dot_detection__instance__data__api__pb2.CacheDetectionInstancesDataByImageIdRequest.FromString,
                    response_serializer=data__grpc__service_dot_protos_dot_detection__instance__data__api__pb2.CacheDetectionInstancesDataByImageIdResponse.SerializeToString,
            ),
            'GetDetectionInstanceDataById': grpc.unary_stream_rpc_method_handler(
                    servicer.GetDetectionInstanceDataById,
                    request_deserializer=data__grpc__service_dot_protos_dot_detection__instance__data__api__pb2.GetDetectionInstanceDataByIdRequest.FromString,
                    response_serializer=data__grpc__service_dot_protos_dot_detection__instance__data__api__pb2.GetDetectionInstanceDataByIdResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'DetectionInstanceDataApi', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class DetectionInstanceDataApi(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CacheDetectionInstancesDataByImageId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/DetectionInstanceDataApi/CacheDetectionInstancesDataByImageId',
            data__grpc__service_dot_protos_dot_detection__instance__data__api__pb2.CacheDetectionInstancesDataByImageIdRequest.SerializeToString,
            data__grpc__service_dot_protos_dot_detection__instance__data__api__pb2.CacheDetectionInstancesDataByImageIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDetectionInstanceDataById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/DetectionInstanceDataApi/GetDetectionInstanceDataById',
            data__grpc__service_dot_protos_dot_detection__instance__data__api__pb2.GetDetectionInstanceDataByIdRequest.SerializeToString,
            data__grpc__service_dot_protos_dot_detection__instance__data__api__pb2.GetDetectionInstanceDataByIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: data_grpc_service/protos/detection_instance_data_api.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from global_vo_grpc_service.protos import detection_instance_api_pb2 as global__vo__grpc__service_dot_protos_dot_detection__instance__api__pb2
from global_vo_grpc_service.protos import utils_pb2 as global__vo__grpc__service_dot_protos_dot_utils__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:data_grpc_service/protos/detection_instance_data_api.proto\x1a:global_vo_grpc_service/protos/detection_instance_api.proto\x1a)global_vo_grpc_service/protos/utils.proto\"?\n+CacheDetectionInstancesDataByImageIdRequest\x12\x10\n\x08image_id\x18\x01 \x01(\x05\"\x81\x01\n,CacheDetectionInstancesDataByImageIdResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12/\n\x13\x64\x65tection_instances\x18\x02 \x03(\x0b\x32\x12.DetectionInstance\"D\n#GetDetectionInstanceDataByIdRequest\x12\x1d\n\x15\x64\x65tection_instance_id\x18\x01 \x01(\x05\"M\n$GetDetectionInstanceDataByIdResponse\x12%\n\x1d\x64\x65tection_instance_data_bytes\x18\x01 \x01(\x0c\x32\x8f\x02\n\x18\x44\x65tectionInstanceDataApi\x12\x83\x01\n$CacheDetectionInstancesDataByImageId\x12,.CacheDetectionInstancesDataByImageIdRequest\x1a-.CacheDetectionInstancesDataByImageIdResponse\x12m\n\x1cGetDetectionInstanceDataById\x12$.GetDetectionInstanceDataByIdRequest\x1a%.GetDetectionInstanceDataByIdResponse0\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'data_grpc_service.protos.detection_instance_data_api_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CACHEDETECTIONINSTANCESDATABYIMAGEIDREQUEST._serialized_start=165
  _CACHEDETECTIONINSTANCESDATABYIMAGEIDREQUEST._serialized_end=228
  _CACHEDETECTIONINSTANCESDATABYIMAGEIDRESPONSE._serialized_start=231
  _CACHEDETECTIONINSTANCESDATABYIMAGEIDRESPONSE._serialized_end=360
  _GETDETECTIONINSTANCEDATABYIDREQUEST._serialized_start=362
  _GETDETECTIONINSTANCEDATABYIDREQUEST._serialized_end=430
  _GETDETECTIONINSTANCEDATABYIDRESPONSE._serialized_start=432
  _GETDETECTIONINSTANCEDATABYIDRESPONSE._serialized_end=509
  _DETECTIONINSTANCEDATAAPI._serialized_start=512
  _DETECTIONINSTANCEDATAAPI._serialized_end=783
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: global_vo_grpc_service/protos/workflow_api.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from global_vo_grpc_service.protos import utils_pb2 as global__vo__grpc__service_dot_protos_dot_utils__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0global_vo_grpc_service/protos/workflow_api.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a)global_vo_grpc_service/protos/utils.proto\x1a\x1cgoogle/protobuf/struct.proto\"\x8e\x02\n\x08Workflow\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x12\n\nmission_id\x18\x02 \x01(\x05\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0c\n\x04type\x18\x04 \x01(\t\x12\x0e\n\x06status\x18\x05 \x01(\t\x12.\n\ncreated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12)\n\x08metadata\x18\x08 \x01(\x0b\x32\x17.google.protobuf.Struct\x12+\n\nextra_data\x18\t \x01(\x0b\x32\x17.google.protobuf.Struct\".\n\x0fWorkflowRequest\x12\x1b\n\x08workflow\x18\x01 \x01(\x0b\x32\t.Workflow\"Q\n\x10WorkflowResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x1b\n\x08workflow\x18\x02 \x01(\x0b\x32\t.Workflow\">\n\x1fTransitionWorkflowStatusRequest\x12\x1b\n\x08workflow\x18\x01 \x01(\x0b\x32\t.Workflow\"a\n TransitionWorkflowStatusResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x1b\n\x08workflow\x18\x02 \x01(\x0b\x32\t.Workflow\"6\n\x17QueueMissionScanRequest\x12\x1b\n\x08workflow\x18\x01 \x01(\x0b\x32\t.Workflow\"Y\n\x18QueueMissionScanResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x1b\n\x08workflow\x18\x02 \x01(\x0b\x32\t.Workflow\"`\n\x1eListQueuedMissionScansResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x1c\n\tworkflows\x18\x02 \x03(\x0b\x32\t.Workflow\"6\n\x17ListMissionScansRequest\x12\x1b\n\x08workflow\x18\x01 \x01(\x0b\x32\t.Workflow\"Z\n\x18ListMissionScansResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x1c\n\tworkflows\x18\x02 \x03(\x0b\x32\t.Workflow\"A\n\"ListRelatedMissionScansByIdRequest\x12\x1b\n\x08workflow\x18\x01 \x01(\x0b\x32\t.Workflow\"e\n#ListRelatedMissionScansByIdResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x1c\n\tworkflows\x18\x02 \x03(\x0b\x32\t.Workflow\"8\n\x19QueueMissionExportRequest\x12\x1b\n\x08workflow\x18\x01 \x01(\x0b\x32\t.Workflow\"[\n\x1aQueueMissionExportResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x1b\n\x08workflow\x18\x02 \x01(\x0b\x32\t.Workflow\"b\n ListQueuedMissionExportsResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x1c\n\tworkflows\x18\x02 \x03(\x0b\x32\t.Workflow\"8\n\x19ListMissionExportsRequest\x12\x1b\n\x08workflow\x18\x01 \x01(\x0b\x32\t.Workflow\"\\\n\x1aListMissionExportsResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x1c\n\tworkflows\x18\x02 \x03(\x0b\x32\t.Workflow\"4\n\x15\x44\x65leteWorkflowRequest\x12\x1b\n\x08workflow\x18\x01 \x01(\x0b\x32\t.Workflow\"W\n\x16\x44\x65leteWorkflowResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x1b\n\x08workflow\x18\x02 \x01(\x0b\x32\t.Workflow2\xb2\x06\n\x0bWorkflowApi\x12;\n\x14\x46indOrCreateWorkflow\x12\x10.WorkflowRequest\x1a\x11.WorkflowResponse\x12_\n\x18TransitionWorkflowStatus\x12 .TransitionWorkflowStatusRequest\x1a!.TransitionWorkflowStatusResponse\x12\x41\n\x0e\x44\x65leteWorkflow\x12\x16.DeleteWorkflowRequest\x1a\x17.DeleteWorkflowResponse\x12M\n\x12QueueMissionExport\x12\x1a.QueueMissionExportRequest\x1a\x1b.QueueMissionExportResponse\x12U\n\x18ListQueuedMissionExports\x12\x16.google.protobuf.Empty\x1a!.ListQueuedMissionExportsResponse\x12M\n\x12ListMissionExports\x12\x1a.ListMissionExportsRequest\x1a\x1b.ListMissionExportsResponse\x12G\n\x10QueueMissionScan\x12\x18.QueueMissionScanRequest\x1a\x19.QueueMissionScanResponse\x12Q\n\x16ListQueuedMissionScans\x12\x16.google.protobuf.Empty\x1a\x1f.ListQueuedMissionScansResponse\x12G\n\x10ListMissionScans\x12\x18.ListMissionScansRequest\x1a\x19.ListMissionScansResponse\x12h\n\x1bListRelatedMissionScansById\x12#.ListRelatedMissionScansByIdRequest\x1a$.ListRelatedMissionScansByIdResponseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'global_vo_grpc_service.protos.workflow_api_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _WORKFLOW._serialized_start=188
  _WORKFLOW._serialized_end=458
  _WORKFLOWREQUEST._serialized_start=460
  _WORKFLOWREQUEST._serialized_end=506
  _WORKFLOWRESPONSE._serialized_start=508
  _WORKFLOWRESPONSE._serialized_end=589
  _TRANSITIONWORKFLOWSTATUSREQUEST._serialized_start=591
  _TRANSITIONWORKFLOWSTATUSREQUEST._serialized_end=653
  _TRANSITIONWORKFLOWSTATUSRESPONSE._serialized_start=655
  _TRANSITIONWORKFLOWSTATUSRESPONSE._serialized_end=752
  _QUEUEMISSIONSCANREQUEST._serialized_start=754
  _QUEUEMISSIONSCANREQUEST._serialized_end=808
  _QUEUEMISSIONSCANRESPONSE._serialized_start=810
  _QUEUEMISSIONSCANRESPONSE._serialized_end=899
  _LISTQUEUEDMISSIONSCANSRESPONSE._serialized_start=901
  _LISTQUEUEDMISSIONSCANSRESPONSE._serialized_end=997
  _LISTMISSIONSCANSREQUEST._serialized_start=999
  _LISTMISSIONSCANSREQUEST._serialized_end=1053
  _LISTMISSIONSCANSRESPONSE._serialized_start=1055
  _LISTMISSIONSCANSRESPONSE._serialized_end=1145
  _LISTRELATEDMISSIONSCANSBYIDREQUEST._serialized_start=1147
  _LISTRELATEDMISSIONSCANSBYIDREQUEST._serialized_end=1212
  _LISTRELATEDMISSIONSCANSBYIDRESPONSE._serialized_start=1214
  _LISTRELATEDMISSIONSCANSBYIDRESPONSE._serialized_end=1315
  _QUEUEMISSIONEXPORTREQUEST._serialized_start=1317
  _QUEUEMISSIONEXPORTREQUEST._serialized_end=1373
  _QUEUEMISSIONEXPORTRESPONSE._serialized_start=1375
  _QUEUEMISSIONEXPORTRESPONSE._serialized_end=1466
  _LISTQUEUEDMISSIONEXPORTSRESPONSE._serialized_start=1468
  _LISTQUEUEDMISSIONEXPORTSRESPONSE._serialized_end=1566
  _LISTMISSIONEXPORTSREQUEST._serialized_start=1568
  _LISTMISSIONEXPORTSREQUEST._serialized_end=1624
  _LISTMISSIONEXPORTSRESPONSE._serialized_start=1626
  _LISTMISSIONEXPORTSRESPONSE._serialized_end=1718
  _DELETEWORKFLOWREQUEST._serialized_start=1720
  _DELETEWORKFLOWREQUEST._serialized_end=1772
  _DELETEWORKFLOWRESPONSE._serialized_start=1774
  _DELETEWORKFLOWRESPONSE._serialized_end=1861
  _WORKFLOWAPI._serialized_start=1864
  _WORKFLOWAPI._serialized_end=2682
# @@protoc_insertion_point(module_scope)
